/*
 * Copyright (c) 2000 Phil Thompson (phil@river-bank.demon.co.uk)
 *
 * The interface to the VPInterpreter type.
 */


#ifndef VPINTERPRETER_H
#define VPINTERPRETER_H

#include <gtk/gtkwidget.h>

#ifdef __cplusplus
extern "C" {
#endif


#define VP_INTERPRETER(o)	GTK_CHECK_CAST((o),vp_interpreter_get_type(),VPInterpreter)
#define VP_INTERPRETER_CLASS(c)	GTK_CHECK_CLASS_CAST((c),vp_interpreter_get_type(),VPInterpreterClass)
#define VP_IS_INTERPRETER(o)	GTK_CHECK_TYPE((o),vp_interpreter_get_type())


/* The contents of this are kept private. */
 
struct pylibContext;
 
 
/* The instance structure. */
 
typedef struct {
	GtkObject		object;
	char			*pre1code;	/* The VP init code. */
	char			*pre2code;	/* The app init code. */
	char			*postcode;	/* The done code. */
	struct pylibContext	*context;	/* The context. */
} VPInterpreter;


/* The class structure. */
 
typedef struct {
	GtkObjectClass	object_class;
	void		(*script_failed)(VPInterpreter *,gchar *,gchar *);
	void		(*internal_error)(VPInterpreter *,gchar *);
} VPInterpreterClass;


extern GtkObject *vp_interpreter_main;

GtkType vp_interpreter_get_type(void);
GtkObject *vp_interpreter_new(GtkWidget *);
void vp_interpreter_set_vp_init_code(GtkObject *,char *);
void vp_interpreter_set_app_init_code(GtkObject *,char *);
void vp_interpreter_execute(GtkObject *,char *);
void vp_interpreter_set_app_done_code(GtkObject *,char *);
void vp_interpreter_add_application_window(GtkObject *,GtkWidget *,const char *);
void vp_interpreter_remove_application_window(GtkObject *,GtkWidget *);
void vp_interpreter_set_argv(GtkObject *,int,char **,GtkWidget *);
void vp_interpreter_set_signals(GtkObject *,char **);
void vp_interpreter_emit_signal(GtkObject *,char *,GtkObject *,GtkWidget *);

/* This is for internal use. */

struct pylibContext *vp_interpreter_get_context(GtkObject *);


#ifdef __cplusplus
}
#endif

#endif
